details: http://www.bx.psu.edu/hg/galaxy/rev/3e391f7192f6
changeset: 1570:3e391f7192f6
user: Nate Coraor <nate(a)bx.psu.edu>
date: Wed Oct 22 14:37:28 2008 -0400
description:
Record a useful info message when a job fails to run because inputs are
deleted. And clarify log messages.
1 file(s) affected in this change:
lib/galaxy/jobs/__init__.py
diffs (66 lines):
diff -r eef0fd813076 -r 4f9042e95e60 lib/galaxy/tools/parameters/basic.py
--- a/lib/galaxy/tools/parameters/basic.py Mon Oct 20 15:09:47 2008 -0400
+++ b/lib/galaxy/tools/parameters/basic.py Mon Oct 20 16:51:51 2008 -0400
@@ -1182,7 +1182,7 @@
return []
def converter_safe( self, other_values, trans ):
- if not hasattr( trans, 'has_multiple_pages' ) or self.tool.has_multiple_pages or not hasattr( trans, 'workflow_building_mode' ) or trans.workflow_building_mode:
+ if self.tool is None or self.tool.has_multiple_pages or not hasattr( trans, 'workflow_building_mode' ) or trans.workflow_building_mode:
return False
if other_values is None:
return True # we don't know other values, so we can't check, assume ok
details: http://www.bx.psu.edu/hg/galaxy/rev/f802eb92a49a
changeset: 1559:f802eb92a49a
user: guru
date: Fri Oct 17 13:02:26 2008 -0400
description:
Added Validator to a bunch of tools..
3 file(s) affected in this change:
tools/extract/liftOver_wrapper.xml
tools/extract/phastOdds/phastOdds_tool.xml
tools/stats/aggregate_binned_scores_in_intervals.xml
diffs (58 lines):
diff -r f5b051c51295 -r f802eb92a49a tools/extract/liftOver_wrapper.xml
--- a/tools/extract/liftOver_wrapper.xml Fri Oct 17 10:46:29 2008 -0400
+++ b/tools/extract/liftOver_wrapper.xml Fri Oct 17 13:02:26 2008 -0400
@@ -3,7 +3,8 @@
<command interpreter="python">liftOver_wrapper.py $input "$out_file1" "$out_file2" $dbkey $to_dbkey</command>
<inputs>
<param format="interval" name="input" type="data" label="Convert coordinates of">
- <validator type="unspecified_build" />
+ <validator type="unspecified_build" />
+ <validator type="dataset_metadata_in_file" filename="liftOver.loc" metadata_name="dbkey" metadata_column="0" message="Liftover mappings are currently not available for the specified build." />
</param>
<param name="to_dbkey" type="select" label="To">
<options from_file="liftOver.loc">
@@ -11,7 +12,7 @@
<column name="value" index="2"/>
<column name="dbkey" index="0"/>
<filter type="data_meta" ref="input" key="dbkey" column="0" />
- </options>
+ </options>
</param>
</inputs>
<outputs>
@@ -39,11 +40,7 @@
.. class:: warningmark
-The **To** list will be empty if we don't carry any liftover mappings corresponding to the genome build of the input dataset.
-
-.. class:: warningmark
-
-This tool will only work on interval datasets with chromosome in column 1, start co-ordinate in column 2 and end co-ordinate in column 3. If this is not the case, it will return empty output datasets.
+This tool will only work on interval datasets with chromosome in column 1, start co-ordinate in column 2 and end co-ordinate in column 3. If this is not the case with any line of the input dataset, the tool will return empty output datasets.
-----
diff -r f5b051c51295 -r f802eb92a49a tools/extract/phastOdds/phastOdds_tool.xml
--- a/tools/extract/phastOdds/phastOdds_tool.xml Fri Oct 17 10:46:29 2008 -0400
+++ b/tools/extract/phastOdds/phastOdds_tool.xml Fri Oct 17 13:02:26 2008 -0400
@@ -4,6 +4,7 @@
<inputs>
<param format="interval" name="input" type="data" label="Interval file">
<validator type="unspecified_build" message="Unspecified build, this tool works with data from genome builds hg17. Click the pencil icon in your history item to set the genome build."/>
+ <validator type="dataset_metadata_in_file" filename="phastOdds.loc" metadata_name="dbkey" metadata_column="0" message="Sequences are currently unavailable for the specified build." />
</param>
<param name="score_file" type="select" label="Available datasets">
<options from_file="phastOdds.loc">
diff -r f5b051c51295 -r f802eb92a49a tools/stats/aggregate_binned_scores_in_intervals.xml
--- a/tools/stats/aggregate_binned_scores_in_intervals.xml Fri Oct 17 10:46:29 2008 -0400
+++ b/tools/stats/aggregate_binned_scores_in_intervals.xml Fri Oct 17 13:02:26 2008 -0400
@@ -8,6 +8,8 @@
<inputs>
<param format="interval" name="input1" type="data" label="Interval file">
<validator type="unspecified_build" message="Unspecified build, this tool works with data from genome builds hg16, hg17 or hg18. Click the pencil icon in your history item to set the genome build."/>
+ <validator type="dataset_metadata_in_file" filename="binned_scores.loc" metadata_name="dbkey" metadata_column="0" message="Data is currently not available for the specified build." />
+
</param>
<conditional name="score_source_type">
<param name="score_source" type="select" label="Score Source">
diff -r df07d0c2830f -r 3e391f7192f6 lib/galaxy/jobs/__init__.py
--- a/lib/galaxy/jobs/__init__.py Wed Oct 22 14:27:57 2008 -0400
+++ b/lib/galaxy/jobs/__init__.py Wed Oct 22 14:37:28 2008 -0400
@@ -15,7 +15,7 @@
log = logging.getLogger( __name__ )
# States for running a job. These are NOT the same as data states
-JOB_WAIT, JOB_ERROR, JOB_OK, JOB_READY, JOB_DELETED = 'wait', 'error', 'ok', 'ready', 'deleted'
+JOB_WAIT, JOB_INPUT_ERROR, JOB_INPUT_DELETED, JOB_OK, JOB_READY, JOB_DELETED = 'wait', 'input_error', 'input_deleted', 'ok', 'ready', 'deleted'
class Sleeper( object ):
"""
@@ -163,8 +163,10 @@
if job_state == JOB_WAIT:
if not self.track_jobs_in_database:
new_waiting.append( job )
- elif job_state == JOB_ERROR:
- log.info( "job %d ended with an error" % job.job_id )
+ elif job_state == JOB_INPUT_ERROR:
+ log.info( "job %d unable to run: one or more inputs in error state" % job.job_id )
+ elif job_state == JOB_INPUT_DELETED:
+ log.info( "job %d unable to run: one or more inputs deleted" % job.job_id )
elif job_state == JOB_READY:
# If special queuing is enabled, put the ready jobs in the special queue
if self.use_policy :
@@ -320,6 +322,7 @@
dataset.flush()
job.state = model.Job.states.ERROR
job.command_line = self.command_line
+ job.info = message
# If the failure is due to a Galaxy framework exception, save
# the traceback
if exception:
@@ -356,12 +359,13 @@
def check_if_ready_to_run( self ):
"""
- Check if a job is ready to run by verifying that each of its input
+ Check if a job is ready to run by verifying that each of its input
datasets is ready (specifically in the OK state). If any input dataset
- has an error, fail the job and return JOB_ERROR. If all input datasets
- are in OK state, return JOB_READY indicating that the job can be
- dispatched. Otherwise, return JOB_WAIT indicating that input datasets
- are still being prepared.
+ has an error, fail the job and return JOB_INPUT_ERROR. If any input
+ dataset is deleted, fail the job and return JOB_INPUT_DELETED. If all
+ input datasets are in OK state, return JOB_READY indicating that the
+ job can be dispatched. Otherwise, return JOB_WAIT indicating that input
+ datasets are still being prepared.
"""
job = model.Job.get( self.job_id )
job.refresh()
@@ -373,11 +377,11 @@
# don't run jobs for which the input dataset was deleted
if idata.deleted == True:
self.fail( "input data %d was deleted before this job ran" % idata.hid )
- return JOB_ERROR
+ return JOB_INPUT_DELETED
# an error in the input data causes us to bail immediately
elif idata.state == idata.states.ERROR:
self.fail( "error in input data %d" % idata.hid )
- return JOB_ERROR
+ return JOB_INPUT_ERROR
elif idata.state != idata.states.OK:
# need to requeue
return JOB_WAIT
details: http://www.bx.psu.edu/hg/galaxy/rev/4f9042e95e60
changeset: 1565:4f9042e95e60
user: Dan Blankenberg <dan(a)bx.psu.edu>
date: Mon Oct 20 16:51:51 2008 -0400
description:
Fix for fix for unit tests.
1 file(s) affected in this change:
lib/galaxy/tools/parameters/basic.py
diffs (12 lines):